@@ -1,9 +1,11 @@
 #!/bin/sh
 # Run this to generate all the initial makefiles, etc.
-# $Id: autogen.sh,v 1.9 1998/10/13 23:23:21 mej Exp $
+# $Id: autogen.sh,v 1.4 2001/06/14 05:31:08 mej Exp $
 
 DIE=0
 
+echo "Generating configuration files for Eterm, please wait...."
+
 (autoconf --version) < /dev/null > /dev/null 2>&1 || {
 	echo
         echo "You must have autoconf installed to compile Eterm."
@@ -32,21 +34,22 @@ if test "$DIE" -eq 1; then
         exit 1
 fi
 
-libtoolize --copy --force
-aclocal $ACLOCAL_FLAGS
-automake --add-missing
-autoconf
+echo "  libtoolize -c -f"
+libtoolize -c -f
+echo "  aclocal -I . $ACLOCAL_FLAGS"
+aclocal -I . $ACLOCAL_FLAGS
+echo "  autoheader"
 autoheader
+echo "  automake -a -c"
+automake -a -c
+echo "  autoconf"
+autoconf
 
-if [ -x config.status -a -z "$*" ]; then
-  ./config.status --recheck
-else
-  if test -z "$*"; then
-    echo "I am going to run ./configure with no arguments - if you wish "
-    echo "to pass any to it, please specify them on the $0 command line."
-    echo "If you do not wish to run ./configure, press Ctrl-C now."
-    trap 'echo "configure aborted" ; exit 0' 1 2 15
-    sleep 1
-  fi
-  ./configure "$@"
+./configure "$@"
+
+if [ -f cvs.motd ]; then
+  echo "ATTENTION CVS Users!"
+  echo ""
+  cat cvs.motd
+  echo ""
 fi
